# Distiset

This section contains the API reference for the Distiset. For more information on how to use the CLI, see [Tutorial - CLI](../sections/how_to_guides/advanced/distiset.md).

:::distilabel.distiset.Distiset
:::distilabel.distiset.create_distiset
